@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hlint
-version: 1.9.26
-id: hlint-1.9.26-c13264b02f49cf69836187748827c12a
-key: hlint_D088B7ym2iB7jl4FKzRthX
+version: 1.9.31
+id: hlint-1.9.31-c6f35c8d90bdf7dd49a61b0973fa4893
+key: hlint_F5ZdsXCk9JhC2WXkguiOwA
 license: BSD3
 copyright: Neil Mitchell 2006-2016
 maintainer: Neil Mitchell <ndmitchell@gmail.com>
@@ -22,29 +22,29 @@ hidden-modules: Paths_hlint Apply CmdLine Grep HLint HsColour Idea
                 HSE.Evaluate HSE.FreeVars HSE.Match HSE.Scope HSE.Type HSE.Util
                 Hint.All Hint.Bracket Hint.Comment Hint.Duplicate Hint.Extensions
                 Hint.Import Hint.Lambda Hint.List Hint.ListRec Hint.Match
-                Hint.Monad Hint.Naming Hint.Pragma Hint.Structure Hint.Type
+                Hint.Monad Hint.Naming Hint.Pattern Hint.Pragma Hint.Type
                 Hint.Unsafe Hint.Util Test.All Test.Annotations Test.InputOutput
                 Test.Proof Test.Translate Test.Util
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.26
-library-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.26
+import-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.31
+library-dirs: /usr/lib/ghc-7.10.3/site-local/hlint-1.9.31
 data-dir: /usr/share/hlint
-hs-libraries: HShlint-1.9.26-D088B7ym2iB7jl4FKzRthX
+hs-libraries: HShlint-1.9.31-F5ZdsXCk9JhC2WXkguiOwA
 depends:
     ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    cmdargs-0.10.13-bef2ab6ecde2bd42e13eb0f01d9aba51
+    cmdargs-0.10.14-ea4d1877c8c5fa6ed8eebd52f962ac3b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cpphs-1.19.3-8cb6c3761dbbd3c20e10f28974c8d246
+    cpphs-1.20.1-46b13f1ef390a545ec653266d5170426
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     extra-1.4.3-ab419342055a04bda9f8a7a264d348c1
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    haskell-src-exts-1.17.1-7afd8d2f109e171c19a1cb4891217e0d
+    haskell-src-exts-1.17.1-3d12ae784d636e2d6ddab796cfe281a8
     hscolour-1.24-b1fe788d8499aec980e06c0cdcf38b18
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     refact-0.3.0.2-cdc0b885b64467c207c7798e46520776
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    uniplate-1.6.12-8f24c9f82f93b9dabcf5d8b53ffd592c
+    uniplate-1.6.12-5a2a0a6de90df137bffce599d35d6149
 haddock-interfaces: /usr/share/doc/hlint/html/hlint.haddock
 haddock-html: /usr/share/doc/hlint/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
